.. image:: https://raw.githubusercontent.com/igordejanovic/Arpeggio/master/art/arpeggio-logo.png
   :height: 100

Arpeggio - PEG parser
=====================

|pypi-badge| |license| |build-status| |docs|

Arpeggio is a recursive descent parser with memoization based on PEG grammars
(aka Packrat parser).

Documentation with tutorials is available `here
<http://igordejanovic.net/Arpeggio/>`_.

**Note:** for a higher level parsing/language tool (i.e., a nicer interface to
Arpeggio) see `textX <https://github.com/igordejanovic/textX>`_.


.. |pypi-badge| image:: https://img.shields.io/pypi/v/Arpeggio.svg
   :target: https://pypi.python.org/pypi/Arpeggio
   :alt: PyPI Version

.. |license| image:: https://img.shields.io/pypi/l/Arpeggio.svg

.. |build-status| image:: https://travis-ci.org/igordejanovic/Arpeggio.svg?branch=master
   :target: https://travis-ci.org/igordejanovic/Arpeggio

.. |docs| image:: https://img.shields.io/badge/docs-latest-green.svg
   :target: http://igordejanovic.net/Arpeggio/
   :alt: Documentation Status
